package com.supermap.samplecode.spatialanalyst;

import java.awt.BorderLayout;
import java.awt.Frame;

import javax.swing.JPanel;
import javax.swing.JFrame;
import javax.swing.JToolBar;
import javax.swing.JButton;
import javax.swing.SwingUtilities;

import com.supermap.data.Workspace;
import com.supermap.ui.MapControl;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

/**
 * <p>
 * Title:表面分析
 * </p>
 * 
 * <p>
 * Description:
 * ============================================================================>
 * ------------------------------版权声明----------------------------
 * 此文件为SuperMap Objects Java 的示范代码 
 * 版权所有：北京超图软件股份有限公司
 * ----------------------------------------------------------------
 * ---------------------SuperMap iObjects Java 示范程序说明------------------------
 * 
 * 1、范例简介：展示表面分析中的提取等值线和等值面功能
 * 2、示例数据：安装目录\SampleData\SurfaceAnalyst\SurfaceAnalyst.smwu
 * 3、关键类型/成员: 
 *      Layers.add 方法
 *      Layers.clear 方法
 *      SurfaceExtractParameter.setDatumValue 方法
 *      SurfaceExtractParameter.setInterval 方法
 *      SurfaceExtractParameter.setSmoothMethod 方法
 *      SurfaceExtractParameter.setSmoothness 方法
 *      SurfaceAnalyst.extractIsoline 方法  
 *      SurfaceAnalyst.extractIsoregion 方法   
 * 4、使用步骤：
 *   (1)选择提取等值线按钮或等值面按钮
 *   (2)在地图中查看做出来的等值线或等值面
 * ------------------------------------------------------------------------------
 * ============================================================================>
 * </p> 
 * 
 * <p>
 * Company: 北京超图软件股份有限公司
 * </p>
 * 
 */
/**
 * <p>
 * Title:Surface Analyst
 * </p>
 * 
 * <p>
 * Description:
 * ============================================================================>
 * ------------------------------CopyRight----------------------------
 *This file contants the sample code of SuperMap Objects Java.
 * Copyright @2005-2009 SuperMap Software Co., Ltd. All Rights Reserved. 
 * ----------------------------------------------------------------
 * ---------------------SuperMap Objects Java Sample Code Description------------------------
 * 
 * 1. Sample Code Description:Display the extracting isoline and isoregion
 * 2. Sample Data Location:Installation directory\\SampleData\SurfaceAnalyst\SurfaceAnalyst.smwu
 * 3. Key Classes/Methods:
 *      Layers.add method
 *      Layers.clear method
 *      SurfaceExtractParameter.setDatumValue method
 *      SurfaceExtractParameter.setInterval method
 *      SurfaceExtractParameter.setSmoothMethod method
 *      SurfaceExtractParameter.setSmoothness method
 *      SurfaceAnalyst.extractIsoline method  
 *      SurfaceAnalyst.extractIsoregion method   
 * 4. Procedures:
 *   (1)Select the buttons.
 *   (2)Display the isoline and the isoregion in the map.
 * ------------------------------------------------------------------------------
 * ============================================================================>
 * </p> 
 * 
 * <p>
 * Company: SuperMap Software Co., Ltd
 * </p>
 * 
 */
public class MainFrame extends JFrame {

	private static final long serialVersionUID = 1L;

	private JPanel m_contentPane;

	private JToolBar m_jToolBar;

	private JButton m_buttonExtractIsoline;

	private JButton m_buttonExtractIsoregion;

	private MapControl m_mapControl;

	private Workspace m_workspace;

	private SampleRun m_sampleRun;

	/**
	 * 程序入口点
	 * The entrance of the programme.
	 */
	public static void main(String[] args) {
		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				MainFrame thisClass = new MainFrame();
				thisClass.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
				thisClass.setVisible(true);
			}
		});
	}

	/**
	 * 构造函数
	 * The constructor.
	 */
	public MainFrame() {
		super();
		initialize();
	}

	/**
	 * 初始化窗体
	 * Initialize the forms.
	 */
	private void initialize() {
		// 最大化显示窗体
		// Maximum display the form.
		this.setExtendedState(Frame.MAXIMIZED_BOTH);
		this.setSize(800, 500);
		this.setContentPane(getJContentPane());
		this.setTitle(getText("thisTitle"));
		this.addWindowListener(new WindowAdapter() {
			// 在主窗体加载时，初始化SampleRun类型，来完成功能的展现
			// Initialize a SampleRun object when loading the main forms.
			public void windowOpened(WindowEvent e) {
				m_workspace = new Workspace();
				m_sampleRun = new SampleRun(m_workspace, m_mapControl);

			}

			// 在窗体关闭时，需要释放相关的资源
			// Dispose the resources when closing the forms.
			public void windowClosing(WindowEvent e) {
				m_mapControl.dispose();
				m_workspace.dispose();
			}

		});
	}

	/**
	 * 获取m_jToolBar
	 * Get the m_jToolBar
	 */
	private JToolBar getJToolBar() {
		if (m_jToolBar == null) {
			m_jToolBar = new JToolBar();
			m_jToolBar.add(getButtonExtractIsoline());
			m_jToolBar.add(getButtonExtractIsoregion());
		}
		return m_jToolBar;
	}

	/**
	 *获取m_buttonExtractIsoline 	
	 *Get the m_buttonExtractIsoline 	
	 */
	private JButton getButtonExtractIsoline() {
		if (m_buttonExtractIsoline == null) {
			m_buttonExtractIsoline = new JButton();
			m_buttonExtractIsoline.setText(getText("m_buttonExtractIsoline"));
			m_buttonExtractIsoline.addActionListener(new ActionListener() {

				public void actionPerformed(ActionEvent e) {
					m_sampleRun.extractIsoline();
				}

			});
		}
		return m_buttonExtractIsoline;
	}

	/**
	 * 获取m_buttonExtractIsoregion
	 * Get the m_buttonExtractIsoregion
	 */
	private JButton getButtonExtractIsoregion() {
		if (m_buttonExtractIsoregion == null) {
			m_buttonExtractIsoregion = new JButton();
			m_buttonExtractIsoregion.setText(getText("m_buttonExtractIsoregion"));
			m_buttonExtractIsoregion.addActionListener(new ActionListener() {

				public void actionPerformed(ActionEvent e) {
					m_sampleRun.extractIsoRegion();
				}

			});
		}
		return m_buttonExtractIsoregion;
	}

	/**
	 * 获取m_mapControl 
	 * Get the m_mapControl 
	 */
	private MapControl getM_mapControl() {
		if (m_mapControl == null) {
			m_mapControl = new MapControl();
		}
		return m_mapControl;
	}

	/**
	 * 获取m_jContentPane
	 * Get the m_jContentPane
	 */
	private JPanel getJContentPane() {
		if (m_contentPane == null) {
			m_contentPane = new JPanel();
			m_contentPane.setLayout(new BorderLayout());
			m_contentPane.add(getJToolBar(), java.awt.BorderLayout.NORTH);
			m_contentPane.add(getM_mapControl(), java.awt.BorderLayout.CENTER);
		}
		return m_contentPane;
	}
	// 根据语言设置text是中文还是英文
	// To change text to English or Chinese by CurrentCulture
	private String getText(String id) {		
		String text = "";
        if (com.supermap.data.Environment.getCurrentCulture().contentEquals("zh-CN"))
        {      	        
        	if(id == "thisTitle")
        	{       		
        		text = "表面分析";
        	}
        	if(id == "m_buttonExtractIsoline")
        	{       		
        		text = "等值线";
        	}
        	if(id == "m_buttonExtractIsoregion")
        	{       		
        		text = "等值面";
        	}
        }
        else
        {
        	if(id == "thisTitle")
        	{       		
        		text = "Surface analyst";
        	}
        	if(id == "m_buttonExtractIsoline")
        	{       		
        		text = "Isoline";
        	}
        	if(id == "m_buttonExtractIsoregion")
        	{       		
        		text = "Isoregion";
        	}
        }        
        return text;	
	}
}

