package com.supermap.samplecode.spatialanalyst;

import java.awt.Color;

import com.supermap.analyst.spatialanalyst.SmoothMethod;
import com.supermap.analyst.spatialanalyst.SurfaceAnalyst;
import com.supermap.analyst.spatialanalyst.SurfaceExtractParameter;
import com.supermap.data.DatasetGrid;
import com.supermap.data.DatasetVector;
import com.supermap.data.Datasource;
import com.supermap.data.Workspace;
import com.supermap.data.WorkspaceConnectionInfo;
import com.supermap.data.WorkspaceType;
import com.supermap.mapping.Layer;
import com.supermap.mapping.LayerSettingVector;
import com.supermap.mapping.ThemeLabel;
import com.supermap.ui.MapControl;

/**
 * <p>
 * Title:表面分析
 * </p>
 * 
 * <p>
 * Description:
 * ============================================================================>
 * ------------------------------版权声明----------------------------
 * 此文件为SuperMap Objects Java 的示范代码 
 * 版权所有：北京超图软件股份有限公司
 * ----------------------------------------------------------------
 * ---------------------SuperMap iObjects Java 示范程序说明------------------------
 * 
 * 1、范例简介：展示表面分析中的提取等值线和等值面功能
 * 2、示例数据：安装目录\SampleData\SurfaceAnalyst\SurfaceAnalyst.smwu
 * 3、关键类型/成员: 
 *      Layers.add 方法
 *      Layers.clear 方法
 *      SurfaceExtractParameter.setDatumValue 方法
 *      SurfaceExtractParameter.setInterval 方法
 *      SurfaceExtractParameter.setSmoothMethod 方法
 *      SurfaceExtractParameter.setSmoothness 方法
 *      SurfaceAnalyst.extractIsoline 方法  
 *      SurfaceAnalyst.extractIsoregion 方法   
 * 4、使用步骤：
 *   (1)选择提取等值线按钮或等值面按钮
 *   (2)在地图中查看做出来的等值线或等值面
 * ------------------------------------------------------------------------------
 * ============================================================================>
 * </p> 
 * 
 * <p>
 * Company: 北京超图软件股份有限公司
 * </p>
 * 
 */
/**
 * <p>
 * Title:Surface Analyst
 * </p>
 * 
 * <p>
 * Description:
 * ============================================================================>
 * ------------------------------CopyRight----------------------------
 *This file contants the sample code of SuperMap Objects Java.
 * Copyright @2005-2009 SuperMap Software Co., Ltd. All Rights Reserved. 
 * ----------------------------------------------------------------
 * ---------------------SuperMap Objects Java Sample Code Description------------------------
 * 
 * 1. Sample Code Description:Display the extracting isoline and isoregion
 * 2. Sample Data Location:Installation directory\\SampleData\SurfaceAnalyst\SurfaceAnalyst.smwu
 * 3. Key Classes/Methods:
 *      Layers.add method
 *      Layers.clear method
 *      SurfaceExtractParameter.setDatumValue method
 *      SurfaceExtractParameter.setInterval method
 *      SurfaceExtractParameter.setSmoothMethod method
 *      SurfaceExtractParameter.setSmoothness method
 *      SurfaceAnalyst.extractIsoline method  
 *      SurfaceAnalyst.extractIsoregion method   
 * 4. Procedures:
 *   (1)Select the buttons.
 *   (2)Display the isoline and the isoregion in the map.
 * ------------------------------------------------------------------------------
 * ============================================================================>
 * </p> 
 * 
 * <p>
 * Company: SuperMap Software Co., Ltd
 * </p>
 * 
 */
public class SampleRun {

	private Workspace m_workspace;

	private MapControl m_mapControl;

	private DatasetGrid m_datasetGrid;

	private Datasource m_datasource;

	private DatasetVector m_datasetVectorLine;

	private DatasetVector m_datasetVectorRegion;

	private double m_minValue;

	private double m_maxValue;

	/**
	 * 根据Workspace和MapControl构造SampleRun对象
	 * Initialize the SampleRun object by the workspace and mapControl object.
	 */
	public SampleRun(Workspace workspace, MapControl mapControl) {
		m_workspace = workspace;
		m_mapControl = mapControl;
		m_mapControl.getMap().setWorkspace(m_workspace);
		initialize();
	}

	/**
	 * 对SampleRun初始化
	 * Initialize the SampleRun
	 */
	private void initialize() {
		try {
			// 打开工作空间
			// Open the workspace.
			WorkspaceConnectionInfo info = new WorkspaceConnectionInfo(
					"../../SampleData/SurfaceAnalyst/SurfaceAnalyst.smwu");
			info.setType(WorkspaceType.SMWU);
			m_workspace.open(info);
			m_datasource = m_workspace.getDatasources().get(0);
			// 得到栅格数据集
			// Get the grid dataset
			m_datasetGrid = (DatasetGrid) m_datasource.getDatasets().get("T1");
			// 得到数据集的最大值和最小值
			// Get the maximum and th4e minimum of the dataset.
			m_minValue = m_datasetGrid.getMinValue();
			m_maxValue = m_datasetGrid.getMaxValue();
			m_mapControl.getMap().getLayers().add(m_datasetGrid, true);
			m_mapControl.getMap().refresh();
		} catch (RuntimeException e) {
			System.out.println(e.getMessage());
		}
	}

	/**
	 * 提取等值线
	 * Extract the isoline.
	 */
	public void extractIsoline() {
		try {
			// 设置表面分析提取操作参数
			// Set the parameters.
			SurfaceExtractParameter parameter = new SurfaceExtractParameter();
			parameter.setDatumValue(m_minValue);
			parameter.setInterval((m_maxValue - m_minValue) / 10);
			parameter.setSmoothMethod(SmoothMethod.POLISH);
			parameter.setSmoothness(3);

			String name = m_datasource.getDatasets().getAvailableDatasetName(
					"del_Line");

			// 提取等值线
			// Extract isoline
			m_datasetVectorLine = SurfaceAnalyst.extractIsoline(parameter,
					m_datasetGrid, m_datasource, name);

			m_mapControl.getMap().getLayers().clear();
			m_mapControl.getMap().getLayers().add(m_datasetGrid, false);
			// 设置线图层的颜色
			// Set line color
			LayerSettingVector setting = new LayerSettingVector();
			setting.getStyle().setLineColor(Color.black);
			setting.getStyle().setLineWidth(0.2);

			m_mapControl.getMap().getLayers().add(m_datasetVectorLine, setting,
					true);
			// 制作标签专题图
			// Make themeLabel
			ThemeLabel label = new ThemeLabel();
			label.setLabelExpression("dZValue");
			label.setNumericPrecision(2);
			label.getUniformStyle().setForeColor(Color.BLACK);
			label.getUniformStyle().setBackColor(Color.WHITE);
			label.getUniformStyle().setOutline(true);

			Layer labelLayer = m_mapControl.getMap().getLayers().add(
					m_datasetVectorLine, label, true);
			labelLayer.setMinVisibleScale(1 / 0.163296);
			m_mapControl.getMap().refresh();
		} catch (RuntimeException e) {
			System.out.println("extractIsoLine:" + e.getMessage());
		}
	}

	/**
	 * 提取等值面
	 * Extract isoregion.
	 */
	public void extractIsoRegion() {
		try {
			// 设置表面分析提取操作参数
			// Set the parameters.
			SurfaceExtractParameter parameter = new SurfaceExtractParameter();
			parameter.setDatumValue(m_minValue);
			parameter.setInterval((m_maxValue - m_minValue) / 9);
			parameter.setSmoothMethod(SmoothMethod.POLISH);
			parameter.setSmoothness(3);

			String name = m_datasource.getDatasets().getAvailableDatasetName(
					"del_Region");

			// 提取等值面
			// Extract isoregion
			m_datasetVectorRegion = SurfaceAnalyst.extractIsoregion(parameter,
					m_datasetGrid, m_datasource, name, null);

			m_mapControl.getMap().getLayers().clear();
			m_mapControl.getMap().refresh();
			m_mapControl.getMap().getLayers().add(m_datasetVectorRegion, true);
			m_mapControl.getMap().refresh();
		} catch (RuntimeException e) {
			System.out.println("extractIsoRegion:" + e.getMessage());
		}
	}

}

